@@ -37,7 +37,8 @@ use LWP::UserAgent;
 use RDF::Simple::Parser::Handler;
 use XML::SAX qw(Namespaces Validation);
 
-my $VERSION = 1.15;
+my
+$VERSION = 1.15;
 
 # Use a hash to implement objects of this type:
 use Class::MethodMaker [
