@@ -16,7 +16,8 @@ use Class::MethodMaker [
                         scalar => [ qw/ stack base genID disallowed qnames result bnode_absolute_prefix / ],
                        ];
 
-my $VERSION = 1.17;
+my
+$VERSION = 1.17;
 
 sub new
   {
