@@ -60,7 +60,8 @@ use Class::MethodMaker [
                         scalar => [ qw/ baseuri path nodeid_prefix / ],
                        ];
 
-my $VERSION = 1.13;
+my
+$VERSION = 1.13;
 
 =item new()
 
